# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mnemosynerpc/session.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mnemosynerpc/session.proto',
  package='mnemosynerpc',
  syntax='proto3',
  serialized_options=_b('Z0github.com/piotrkowalczuk/mnemosyne/mnemosynerpc'),
  serialized_pb=_b('\n\x1amnemosynerpc/session.proto\x12\x0cmnemosynerpc\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xea\x01\n\x07Session\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\nsubject_id\x18\x02 \x01(\t\x12\x16\n\x0esubject_client\x18\x03 \x01(\t\x12+\n\x03\x62\x61g\x18\x04 \x03(\x0b\x32\x1e.mnemosynerpc.Session.BagEntry\x12-\n\texpire_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rrefresh_token\x18\x06 \x01(\t\x1a*\n\x08\x42\x61gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\nGetRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"5\n\x0bGetResponse\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"9\n\x0f\x43ontextResponse\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"V\n\x0bListRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\r\n\x05limit\x18\x02 \x01(\x03\x12\"\n\x05query\x18\x0b \x01(\x0b\x32\x13.mnemosynerpc.QueryJ\x04\x08\x03\x10\x0b\"7\n\x0cListResponse\x12\'\n\x08sessions\x18\x01 \x03(\x0b\x32\x15.mnemosynerpc.Session\"\x84\x01\n\x05Query\x12\x32\n\x0e\x65xpire_at_from\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65xpire_at_to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rrefresh_token\x18\x03 \x01(\t\"%\n\rExistsRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"6\n\x0cStartRequest\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"7\n\rStartResponse\x12&\n\x07session\x18\x01 \x01(\x0b\x32\x15.mnemosynerpc.Session\"&\n\x0e\x41\x62\x61ndonRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"C\n\x0fSetValueRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"t\n\x10SetValueResponse\x12\x34\n\x03\x62\x61g\x18\x01 \x03(\x0b\x32\'.mnemosynerpc.SetValueResponse.BagEntry\x1a*\n\x08\x42\x61gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n\rDeleteRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x32\n\x0e\x65xpire_at_from\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65xpire_at_to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rrefresh_token\x18\x04 \x01(\t\x12\x12\n\nsubject_id\x18\x05 \x01(\t2\xb6\x04\n\x0eSessionManager\x12<\n\x03Get\x12\x18.mnemosynerpc.GetRequest\x1a\x19.mnemosynerpc.GetResponse\"\x00\x12\x42\n\x07\x43ontext\x12\x16.google.protobuf.Empty\x1a\x1d.mnemosynerpc.ContextResponse\"\x00\x12?\n\x04List\x12\x19.mnemosynerpc.ListRequest\x1a\x1a.mnemosynerpc.ListResponse\"\x00\x12\x43\n\x06\x45xists\x12\x1b.mnemosynerpc.ExistsRequest\x1a\x1a.google.protobuf.BoolValue\"\x00\x12\x42\n\x05Start\x12\x1a.mnemosynerpc.StartRequest\x1a\x1b.mnemosynerpc.StartResponse\"\x00\x12\x45\n\x07\x41\x62\x61ndon\x12\x1c.mnemosynerpc.AbandonRequest\x1a\x1a.google.protobuf.BoolValue\"\x00\x12K\n\x08SetValue\x12\x1d.mnemosynerpc.SetValueRequest\x1a\x1e.mnemosynerpc.SetValueResponse\"\x00\x12\x44\n\x06\x44\x65lete\x12\x1b.mnemosynerpc.DeleteRequest\x1a\x1b.google.protobuf.Int64Value\"\x00\x42\x32Z0github.com/piotrkowalczuk/mnemosyne/mnemosynerpcb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_SESSION_BAGENTRY = _descriptor.Descriptor(
  name='BagEntry',
  full_name='mnemosynerpc.Session.BagEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mnemosynerpc.Session.BagEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mnemosynerpc.Session.BagEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=373,
)

_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='mnemosynerpc.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.Session.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='mnemosynerpc.Session.subject_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject_client', full_name='mnemosynerpc.Session.subject_client', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bag', full_name='mnemosynerpc.Session.bag', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expire_at', full_name='mnemosynerpc.Session.expire_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='mnemosynerpc.Session.refresh_token', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SESSION_BAGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=373,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='mnemosynerpc.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.GetRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=409,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='mnemosynerpc.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.GetResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=464,
)


_CONTEXTRESPONSE = _descriptor.Descriptor(
  name='ContextResponse',
  full_name='mnemosynerpc.ContextResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.ContextResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=523,
)


_LISTREQUEST = _descriptor.Descriptor(
  name='ListRequest',
  full_name='mnemosynerpc.ListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='mnemosynerpc.ListRequest.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='mnemosynerpc.ListRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='mnemosynerpc.ListRequest.query', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=611,
)


_LISTRESPONSE = _descriptor.Descriptor(
  name='ListResponse',
  full_name='mnemosynerpc.ListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessions', full_name='mnemosynerpc.ListResponse.sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=668,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='mnemosynerpc.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expire_at_from', full_name='mnemosynerpc.Query.expire_at_from', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expire_at_to', full_name='mnemosynerpc.Query.expire_at_to', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='mnemosynerpc.Query.refresh_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=671,
  serialized_end=803,
)


_EXISTSREQUEST = _descriptor.Descriptor(
  name='ExistsRequest',
  full_name='mnemosynerpc.ExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.ExistsRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=805,
  serialized_end=842,
)


_STARTREQUEST = _descriptor.Descriptor(
  name='StartRequest',
  full_name='mnemosynerpc.StartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.StartRequest.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=898,
)


_STARTRESPONSE = _descriptor.Descriptor(
  name='StartResponse',
  full_name='mnemosynerpc.StartResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='mnemosynerpc.StartResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=955,
)


_ABANDONREQUEST = _descriptor.Descriptor(
  name='AbandonRequest',
  full_name='mnemosynerpc.AbandonRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.AbandonRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=995,
)


_SETVALUEREQUEST = _descriptor.Descriptor(
  name='SetValueRequest',
  full_name='mnemosynerpc.SetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.SetValueRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='mnemosynerpc.SetValueRequest.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mnemosynerpc.SetValueRequest.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=997,
  serialized_end=1064,
)


_SETVALUERESPONSE_BAGENTRY = _descriptor.Descriptor(
  name='BagEntry',
  full_name='mnemosynerpc.SetValueResponse.BagEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mnemosynerpc.SetValueResponse.BagEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mnemosynerpc.SetValueResponse.BagEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=373,
)

_SETVALUERESPONSE = _descriptor.Descriptor(
  name='SetValueResponse',
  full_name='mnemosynerpc.SetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bag', full_name='mnemosynerpc.SetValueResponse.bag', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SETVALUERESPONSE_BAGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1182,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='mnemosynerpc.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='mnemosynerpc.DeleteRequest.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expire_at_from', full_name='mnemosynerpc.DeleteRequest.expire_at_from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expire_at_to', full_name='mnemosynerpc.DeleteRequest.expire_at_to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='mnemosynerpc.DeleteRequest.refresh_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='mnemosynerpc.DeleteRequest.subject_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1367,
)

_SESSION_BAGENTRY.containing_type = _SESSION
_SESSION.fields_by_name['bag'].message_type = _SESSION_BAGENTRY
_SESSION.fields_by_name['expire_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETRESPONSE.fields_by_name['session'].message_type = _SESSION
_CONTEXTRESPONSE.fields_by_name['session'].message_type = _SESSION
_LISTREQUEST.fields_by_name['query'].message_type = _QUERY
_LISTRESPONSE.fields_by_name['sessions'].message_type = _SESSION
_QUERY.fields_by_name['expire_at_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERY.fields_by_name['expire_at_to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STARTREQUEST.fields_by_name['session'].message_type = _SESSION
_STARTRESPONSE.fields_by_name['session'].message_type = _SESSION
_SETVALUERESPONSE_BAGENTRY.containing_type = _SETVALUERESPONSE
_SETVALUERESPONSE.fields_by_name['bag'].message_type = _SETVALUERESPONSE_BAGENTRY
_DELETEREQUEST.fields_by_name['expire_at_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DELETEREQUEST.fields_by_name['expire_at_to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['ContextResponse'] = _CONTEXTRESPONSE
DESCRIPTOR.message_types_by_name['ListRequest'] = _LISTREQUEST
DESCRIPTOR.message_types_by_name['ListResponse'] = _LISTRESPONSE
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['ExistsRequest'] = _EXISTSREQUEST
DESCRIPTOR.message_types_by_name['StartRequest'] = _STARTREQUEST
DESCRIPTOR.message_types_by_name['StartResponse'] = _STARTRESPONSE
DESCRIPTOR.message_types_by_name['AbandonRequest'] = _ABANDONREQUEST
DESCRIPTOR.message_types_by_name['SetValueRequest'] = _SETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetValueResponse'] = _SETVALUERESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), dict(

  BagEntry = _reflection.GeneratedProtocolMessageType('BagEntry', (_message.Message,), dict(
    DESCRIPTOR = _SESSION_BAGENTRY,
    __module__ = 'mnemosynerpc.session_pb2'
    # @@protoc_insertion_point(class_scope:mnemosynerpc.Session.BagEntry)
    ))
  ,
  DESCRIPTOR = _SESSION,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.Session)
  ))
_sym_db.RegisterMessage(Session)
_sym_db.RegisterMessage(Session.BagEntry)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

ContextResponse = _reflection.GeneratedProtocolMessageType('ContextResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONTEXTRESPONSE,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ContextResponse)
  ))
_sym_db.RegisterMessage(ContextResponse)

ListRequest = _reflection.GeneratedProtocolMessageType('ListRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTREQUEST,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ListRequest)
  ))
_sym_db.RegisterMessage(ListRequest)

ListResponse = _reflection.GeneratedProtocolMessageType('ListResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRESPONSE,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ListResponse)
  ))
_sym_db.RegisterMessage(ListResponse)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), dict(
  DESCRIPTOR = _QUERY,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.Query)
  ))
_sym_db.RegisterMessage(Query)

ExistsRequest = _reflection.GeneratedProtocolMessageType('ExistsRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXISTSREQUEST,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.ExistsRequest)
  ))
_sym_db.RegisterMessage(ExistsRequest)

StartRequest = _reflection.GeneratedProtocolMessageType('StartRequest', (_message.Message,), dict(
  DESCRIPTOR = _STARTREQUEST,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.StartRequest)
  ))
_sym_db.RegisterMessage(StartRequest)

StartResponse = _reflection.GeneratedProtocolMessageType('StartResponse', (_message.Message,), dict(
  DESCRIPTOR = _STARTRESPONSE,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.StartResponse)
  ))
_sym_db.RegisterMessage(StartResponse)

AbandonRequest = _reflection.GeneratedProtocolMessageType('AbandonRequest', (_message.Message,), dict(
  DESCRIPTOR = _ABANDONREQUEST,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.AbandonRequest)
  ))
_sym_db.RegisterMessage(AbandonRequest)

SetValueRequest = _reflection.GeneratedProtocolMessageType('SetValueRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETVALUEREQUEST,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.SetValueRequest)
  ))
_sym_db.RegisterMessage(SetValueRequest)

SetValueResponse = _reflection.GeneratedProtocolMessageType('SetValueResponse', (_message.Message,), dict(

  BagEntry = _reflection.GeneratedProtocolMessageType('BagEntry', (_message.Message,), dict(
    DESCRIPTOR = _SETVALUERESPONSE_BAGENTRY,
    __module__ = 'mnemosynerpc.session_pb2'
    # @@protoc_insertion_point(class_scope:mnemosynerpc.SetValueResponse.BagEntry)
    ))
  ,
  DESCRIPTOR = _SETVALUERESPONSE,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.SetValueResponse)
  ))
_sym_db.RegisterMessage(SetValueResponse)
_sym_db.RegisterMessage(SetValueResponse.BagEntry)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'mnemosynerpc.session_pb2'
  # @@protoc_insertion_point(class_scope:mnemosynerpc.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)


DESCRIPTOR._options = None
_SESSION_BAGENTRY._options = None
_SETVALUERESPONSE_BAGENTRY._options = None

_SESSIONMANAGER = _descriptor.ServiceDescriptor(
  name='SessionManager',
  full_name='mnemosynerpc.SessionManager',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1370,
  serialized_end=1936,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='mnemosynerpc.SessionManager.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Context',
    full_name='mnemosynerpc.SessionManager.Context',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CONTEXTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='mnemosynerpc.SessionManager.List',
    index=2,
    containing_service=None,
    input_type=_LISTREQUEST,
    output_type=_LISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Exists',
    full_name='mnemosynerpc.SessionManager.Exists',
    index=3,
    containing_service=None,
    input_type=_EXISTSREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='mnemosynerpc.SessionManager.Start',
    index=4,
    containing_service=None,
    input_type=_STARTREQUEST,
    output_type=_STARTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Abandon',
    full_name='mnemosynerpc.SessionManager.Abandon',
    index=5,
    containing_service=None,
    input_type=_ABANDONREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetValue',
    full_name='mnemosynerpc.SessionManager.SetValue',
    index=6,
    containing_service=None,
    input_type=_SETVALUEREQUEST,
    output_type=_SETVALUERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='mnemosynerpc.SessionManager.Delete',
    index=7,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._INT64VALUE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SESSIONMANAGER)

DESCRIPTOR.services_by_name['SessionManager'] = _SESSIONMANAGER

# @@protoc_insertion_point(module_scope)
